@@ -1,18 +1,33 @@
-# This demo solves the time-dependent convection-diffusion equation by
-# a least-squares stabilized cG(1)cG(1) method. The velocity field used
-# in the simulation is the output from the Stokes (Taylor-Hood) demo.
-# The sub domains for the different boundary conditions are computed
-# by the demo program in src/demo/subdomains.
+# Copyright (C) 2007 Kristian B. Oelgaard
+#
+# This file is part of SyFi.
+#
+# SyFi is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 2 of the License, or
+# (at your option) any later version.
+#
+# SyFi is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with SyFi. If not, see <http://www.gnu.org/licenses/>.
 #
 # Modified by Anders Logg, 2008
 # Modified by Johan Hake, 2008
 # Modified by Garth N. Wells, 2009
 # Modified by Kent-Andre Mardal, 2009 to work with SFC 
-
-__author__ = "Kristian B. Oelgaard (k.b.oelgaard@tudelft.nl)"
-__date__ = "2007-11-14 -- 2008-01-04"
-__copyright__ = "Copyright (C) 2007 Kristian B. Oelgaard"
-__license__  = "GNU LGPL Version 2.1"
+#
+# First added:  2007-11-14
+# Last changed: 2008-01-04
+#
+# This demo solves the time-dependent convection-diffusion equation by
+# a least-squares stabilized cG(1)cG(1) method. The velocity field used
+# in the simulation is the output from the Stokes (Taylor-Hood) demo.
+# The sub domains for the different boundary conditions are computed
+# by the demo program in src/demo/subdomains.
 
 from dolfin import *
 
@@ -26,7 +41,7 @@ sub_domains = MeshFunction("uint", mesh, "subdomains.xml.gz");
 Q = FunctionSpace(mesh, "CG", 1)
 V = VectorFunctionSpace(mesh, "CG", 2)
 
-# Create velocity Function 
+# Create velocity Function
 velocity = Constant((-1,0,0.0)) 
 
 # Initialise source function and previous solution function
@@ -73,17 +88,17 @@ while t < T:
     # Assemble vector and apply boundary conditions
     b = assemble(L)
     bc.apply(A, b)
-    
+
     # Solve the linear system
     solve(A, u1.vector(), b)
-    
+
     # Plot solution
     figure(0)
     plot(u1, title="u")
 
     # Save the solution to file
     out_file << u1
-    
+
     # Compute sensitivity to c
     u0.assign(u1)
     sb = assemble(sL)
@@ -97,3 +112,4 @@ while t < T:
 
 # Hold plot
 interactive()
+
