@@ -9,7 +9,6 @@ class Source(Expression):
     def eval(self, values, x): 
         values[0] = -2 + math.exp(x[0]*x[0]) 
 
-
 class Solution(Expression): 
     def eval(self, values, x): 
         values[0] = x[0]*x[0] 
@@ -20,13 +19,12 @@ class DirichletBoundary(SubDomain):
 
 # Geometry
 N = 80  
-
 mesh = UnitSquare(N,N)
 
 # Function spaces
 X = FunctionSpace(mesh, 'CG', 1)
 
-# function 
+# Unknown function 
 U = Function(X)
 
 # Basis functions 
@@ -34,30 +32,23 @@ v = TestFunction(X)
 u = TrialFunction(X)
 
 # Source term 
-source = Source()
+source = Source(element=X.ufl_element())
 s = Function(X)
 s.interpolate(source)
 
 # Forms
-F = inner(grad(U),grad(v))*dx + ufl.exp(U)*v*dx  
+F = inner(grad(U),grad(v))*dx + exp(U)*v*dx  
 J = derivative(F, U, u)
 
 # Analytical solution 
-solution = Solution(X)
-sol = project(solution,X)
-
+solution = Solution(element=X.ufl_element())
+sol = project(solution, X)
 
 # Solve nonlinear variational problem
 dirichlet_boundary = DirichletBoundary()
 bc = DirichletBC(X, sol, dirichlet_boundary)
-#problem = VariationalProblem(J, F, bc, nonlinear=True)
 
-problem = VariationalProblem(J, F, bc, nonlinear=True)
-problem.solve(U)
-
-plot(sol)
-plot(U)
-interactive()
+solve(F == 0, U, bc, J=J)
 
 # Write solution to file
 file = File("u.pvd") 
@@ -66,4 +57,7 @@ file << U
 file = File("sol.pvd") 
 file << sol 
 
-
+# Plot and wait
+plot(sol)
+plot(U)
+interactive()
