@@ -1,5 +1,19 @@
-// Copyright (C) 2009-2009 Martin Sandve Alnæs
-// Licensed under the GNU LGPL Version 3.0.
+// Copyright (C) 2009 Martin Sandve Alnes
+//
+// This file is part of SyFi.
+//
+// SyFi is free software: you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 2 of the License, or
+// (at your option) any later version.
+//
+// SyFi is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with SyFi. If not, see <http://www.gnu.org/licenses/>.
 //
 // First added:  2009-01-01
 // Last changed: 2009-04-01
@@ -8,6 +22,7 @@
 
 #include <iostream>
 #include <dolfin.h>
+#include <cmath>
 #include "generated_code/HyperElasticity1D.h"
 
 using namespace dolfin;
@@ -37,7 +52,7 @@ public:
     const double b = B_VALUE;
     const double K = K_VALUE;
     // Matching solution u = sin(x) - x:
-    values[0] = -K*exp((1.0/4.0)*pow( pow(cos(x[0]),2.0)-1.0,2.0)*b)*( pow(cos(x[0]),2.0)-1.0)*sin(x[0])*b+-2.0*K*exp((1.0/4.0)*pow( pow(cos(x[0]),2.0)-1.0,2.0)*b)*pow(cos(x[0]),2.0)*sin(x[0])*b-K*exp((1.0/4.0)*pow( pow(cos(x[0]),2.0)-1.0,2.0)*b)*pow(cos(x[0]),2.0)*pow( pow(cos(x[0]),2.0)-1.0,2.0)*sin(x[0])*(b*b);
+    values[0] = -K*exp((1.0/4.0)*std::pow( std::pow(cos(x[0]),2.0)-1.0,2.0)*b)*( std::pow(cos(x[0]),2.0)-1.0)*sin(x[0])*b+-2.0*K*exp((1.0/4.0)*std::pow( std::pow(cos(x[0]),2.0)-1.0,2.0)*b)*std::pow(cos(x[0]),2.0)*sin(x[0])*b-K*exp((1.0/4.0)*std::pow( std::pow(cos(x[0]),2.0)-1.0,2.0)*b)*std::pow(cos(x[0]),2.0)*std::pow( std::pow(cos(x[0]),2.0)-1.0,2.0)*sin(x[0])*(b*b);
   }
 };
 
@@ -95,14 +110,14 @@ int main()
     // Boundary conditions
     DirichletBoundary boundary;
     DirichletBC bc(V, usol, boundary);
-    
+
     // Solve variational problem
-    VariationalProblem problem(a, L, bc, true);
-    problem.solve(u);
-    
+    solve(a==L, u, bc); 
+
     // Compute F at u
     Vector F;
-    problem.F(F, u.vector());
+    assemble(F, L);
+    //problem.F(F, u.vector());
     cout << "Norm of F = " << F.norm("l2") << endl;
     cout << "Min  of F = " << F.min() << endl;
     cout << "Max  of F = " << F.max() << endl;
