@@ -1,5 +1,19 @@
-// Copyright (C) 2009-2009 Martin Sandve Alnæs
-// Licensed under the GNU LGPL Version 3.0.
+// Copyright (C) 2009 Martin Sandve Alnes
+//
+// This file is part of SyFi.
+//
+// SyFi is free software: you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 2 of the License, or
+// (at your option) any later version.
+//
+// SyFi is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with SyFi. If not, see <http://www.gnu.org/licenses/>.
 //
 // First added:  2009-01-01
 // Last changed: 2009-04-01
@@ -93,9 +107,6 @@ int main(int argc, char**argv)
     DirichletBoundary boundary;
     DirichletBC bc(V, ubc, boundary);
     
-    info("Variational problem");
-    VariationalProblem problem(a, L, bc, true);
-
     // Compute integral of strain energy over domain, should be zero
     double energy = 0.0;
     energy = assemble(M);
@@ -103,7 +114,7 @@ int main(int argc, char**argv)
 
     // Solve!
     info("Solving");
-    problem.solve(u);
+    solve(a==L, u, bc); 
 
     // Compute integral of strain energy over domain
     energy = assemble(M);
