@@ -1,5 +1,19 @@
-// Copyright (C) 2006-2009 Johan Jansson and Anders Logg.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2006-2009 Johan Jansson and Anders Logg
+//
+// This file is part of SyFi.
+//
+// SyFi is free software: you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 2 of the License, or
+// (at your option) any later version.
+//
+// SyFi is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with SyFi. If not, see <http://www.gnu.org/licenses/>.
 //
 // Modified by Garth N. Wells 2008
 //
@@ -74,7 +88,7 @@ int main()
   };
 
   // Read mesh and create function space
-  Mesh mesh("../../data/gear.xml.gz");
+  Mesh mesh("../../../data/gear.xml.gz");
   LinearElasticity::BilinearForm::TrialSpace V(mesh);
 
   // Create right-hand side
@@ -109,11 +123,9 @@ int main()
   LinearElasticity::LinearForm L(V);
   L.f = f;
 
-  VariationalProblem problem(a, L, bcs);
-
   // Solve PDE (using direct solver)
   Function u(V);
-  problem.solve(u);
+  solve(a==L, u, bcs);
 
   // Plot solution
   //plot(u, "displacement");
