@@ -2,16 +2,30 @@
 """This demo program solves the equations of static linear elasticity
 for a gear clamped at two of its ends and twisted 30 degrees."""
 
-__author__ = "Kristian B. Oelgaard (k.b.oelgaard@tudelft.nl)"
-__date__ = "2007-11-14 -- 2009-02-25"
-__copyright__ = "Copyright (C) 2007 Kristian B. Oelgaard"
-__license__  = "GNU LGPL Version 2.1"
-
+# Copyright (C) 2007 Kristian B. Oelgaard
+#
+# This file is part of SyFi.
+#
+# SyFi is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 2 of the License, or
+# (at your option) any later version.
+#
+# SyFi is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with SyFi. If not, see <http://www.gnu.org/licenses/>.
+#
 # Modified by Anders Logg, 2008.
 # Modified by Kent-Andre Mardal, 2010.
+#
+# First added:  2007-11-14
+# Last changed: 2009-02-25
 
 from dolfin import *
-
 parameters["form_compiler"]["name"]= "sfc"
 
 # Load mesh and define function space
@@ -25,9 +39,10 @@ class Left(SubDomain):
 
 # Dirichlet boundary condition for rotation at right end
 class Rotation(Expression):
-    def dim(self): return 3
-    def eval(self, values, x):
+    def value_shape(self):
+        return (3,)
 
+    def eval(self, values, x):
         # Center of rotation
         y0 = 0.5
         z0 = 0.219
@@ -78,15 +93,15 @@ c = Constant((0, 0, 0))
 bcl = DirichletBC(V, c, Left())
 
 # Set up boundary condition at right end
-r = Rotation(V)
+r = Rotation()
 bcr = DirichletBC(V, r, Right())
 
 # Set up boundary conditions
 bcs = [bcl, bcr]
 
 # Set up PDE and solve
-problem = VariationalProblem(a, L, bcs)
-u = problem.solve()
+u = Function(V)
+solve(a==L, u, bcs)
 
 # Save solution to VTK format
 vtk_file = File("elasticity.pvd")
@@ -101,4 +116,3 @@ plot(mesh)
 
 # Hold plots
 interactive()
-
