@@ -1,5 +1,4 @@
 
-import math 
 from dolfin import *
 
 parameters["form_compiler"]["name"]= "sfc"
@@ -8,7 +7,6 @@ class Source(Expression):
     def eval(self, values, x): 
         values[0] = -1.0+((0.5)*x[0]+(0.5)*x[1])**6
 
-
 class Solution(Expression): 
     def eval(self, values, x): 
         values[0] = (0.5*(x[0] + x[1]))**2     
@@ -20,13 +18,12 @@ class DirichletBoundary(SubDomain):
 # Geometry
 N = 80  
 P = 4 
-
-mesh = UnitSquare(N,N)
+mesh = UnitSquare(N, N)
 
 # Function spaces
 X = FunctionSpace(mesh, 'CG', 1)
 
-# function 
+# Unknown function
 U = Function(X)
 
 # Basis functions 
@@ -34,29 +31,21 @@ v = TestFunction(X)
 u = TrialFunction(X)
 
 # Source term 
-source = Source()
+source = Source(element=X.ufl_element())
 
 # Forms
 L = inner(grad(U),grad(U))*dx + U**P*dx + source*U*dx 
 F = derivative(L, U, v)
-J = derivative(F, U, u)
 
 # Analytical solution 
-solution = Solution(X)
-sol = project(solution,X)
-
+solution = Solution(element=X.ufl_element())
+sol = project(solution, X)
 
 # Solve nonlinear variational problem
 dirichlet_boundary = DirichletBoundary()
 bc = DirichletBC(X, solution, dirichlet_boundary)
-#problem = VariationalProblem(J, F, bc, nonlinear=True)
 
-problem = VariationalProblem(J, F, bc, nonlinear=True)
-problem.solve(U)
-
-plot(sol)
-plot(U)
-interactive()
+solve(F==0, U, bc)
 
 # Write solution to file
 file = File("u.pvd") 
@@ -65,4 +54,7 @@ file << U
 file = File("u0.pvd") 
 file << sol 
 
-
+# Plot and wait
+plot(sol)
+plot(U)
+interactive()
