@@ -12,16 +12,29 @@ and boundary conditions given by
     du/dx = 0 for x = 1
 """
 
-__author__ = "Kristian B. Oelgaard (k.b.oelgaard@tudelft.nl)"
-__date__ = "2007-11-28 -- 2008-12-19"
-__copyright__ = "Copyright (C) 2007 Kristian B. Oelgaard"
-__license__  = "GNU LGPL Version 2.1"
+# Copyright (C) 2007 Kristian B. Oelgaard
+#
+# This file is part of SyFi.
+#
+# SyFi is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 2 of the License, or
+# (at your option) any later version.
+#
+# SyFi is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with SyFi. If not, see <http://www.gnu.org/licenses/>.
+#
+# First added:  2007-11-28
+# Last changed: 2008-12-19
 
 from dolfin import *
-
 parameters["form_compiler"]["name"] = "sfc"
 
-
 # Create mesh and function space
 mesh = UnitInterval(50)
 V = FunctionSpace(mesh, "CG", 1)
@@ -45,12 +58,13 @@ u0 = Constant(0.0)
 bc = DirichletBC(V, u0, DirichletBoundary())
 
 # Solve PDE and plot solution
-problem = VariationalProblem(a, L, bc)
-u = problem.solve()
+u = Function(V)
+solve(a==L, u, bc)
 
 # Save solution to file
 file = File("poisson.pvd")
 file << u
 
 # Plot solution
-plot(u, interactive=True)
+plot(u)
+interactive()
