@@ -1,5 +1,19 @@
-// Copyright (C) 2009-2009 Martin Sandve Alnæs
-// Licensed under the GNU LGPL Version 3.0.
+// Copyright (C) 2009 Martin Sandve Alnes
+//
+// This file is part of SyFi.
+//
+// SyFi is free software: you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 2 of the License, or
+// (at your option) any later version.
+//
+// SyFi is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with SyFi. If not, see <http://www.gnu.org/licenses/>.
 //
 // First added:  2009-01-01
 // Last changed: 2009-04-01
@@ -58,16 +72,14 @@ int main(int argc, char ** argv)
   a.c = c;
   L.f = f;
 
-  VariationalProblem problem(a, L);
-  problem.solve(u);
-
-
+  u = Function(V); 
+  solve(a==L, u);
  
   // Interpolate f onto the discrete space V
   Source f2;
   Function fi(V);
-  fi = f2; 
-  
+  fi.interpolate(f2); 
+ 
   File u_file("u.pvd");
   u_file << u;
   File f_file("f.pvd");
