@@ -1,5 +1,19 @@
-// Copyright (C) 2009-2009 Martin Sandve Alnæs
-// Licensed under the GNU LGPL Version 3.0.
+// Copyright (C) 2009 Martin Sandve Alnes
+//
+// This file is part of SyFi.
+//
+// SyFi is free software: you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 2 of the License, or
+// (at your option) any later version.
+//
+// SyFi is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with SyFi. If not, see <http://www.gnu.org/licenses/>.
 //
 // First added:  2009-01-01
 // Last changed: 2009-04-01
@@ -72,9 +86,10 @@ int main()
     unsigned n = 100;
     UnitSquare mesh(n, n);
 
-    MeshFunction<unsigned> domains(mesh, 2);
+    //MeshFunction<unsigned> domains(mesh, 2);
+    boost::shared_ptr< MeshFunction<unsigned> > domains(new MeshFunction<unsigned>(mesh, 2));
     ValueDomain vdomain;
-    vdomain.mark(domains, 1);
+    vdomain.mark(*domains, 1);
     
     BilinearForm::TrialSpace V(mesh);
     CoefficientSpace_f F(mesh);
@@ -82,7 +97,10 @@ int main()
     
     BilinearForm a(V, V);
     LinearForm L(V);
-    
+
+    L.set_cell_domains(domains);
+    a.set_cell_domains(domains);
+
     Source f;
     Value g;
     BoundaryValue ubc;
@@ -93,10 +111,7 @@ int main()
     DirichletBoundary boundary;
     DirichletBC bc(V, ubc, boundary);
     
-    vector<const BoundaryCondition*> bcs;
-    bcs.push_back(&bc);
-
-    VariationalProblem problem(a, L, bcs, &domains, 0, 0, false);
+    VariationalProblem problem(a, L, bc);
     Function u(V);
     problem.solve(u);
     
@@ -105,4 +120,3 @@ int main()
     
     //plot(u);
 }
-
