@@ -9,4 +9,10 @@ for f in glob("*"):
             if os.path.exists("Makefile"):
                 os.system("make clean")
             os.chdir("..")
+        if os.path.isdir("python"):
+            os.chdir("python")
+            if os.path.exists("Makefile"):
+                os.system("make clean")
+            os.chdir("..")
+
         os.chdir("..")
