@@ -13,7 +13,7 @@ from ufl import *
 
 # Options handling
 from sfc.common import version
-from sfc.common import default_options as default_parameters
+from sfc.common import default_parameters
 from sfc.common import set_logging_level
 
 
@@ -26,7 +26,6 @@ from sfc.common import set_logging_level
 # Function for compiling a form and importing it on the fly
 from sfc.jit import generate_code, cache_signature, jit, jitf
 
-__version__ = "0.6.1"
+__version__ = "1.0.0"
 __author__ = "Martin Sandve Alnæs"
 
-
