@@ -1,13 +1,28 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 """
-This module contains code generation tools for the ufc::dof_map class.
+This module contains code generation tools for the ufc::dofmap class.
 """
 
-__author__ = "Martin Sandve Alnes"
-__date__   = "2008-08-13 -- 2009-05-14"
-__copyright__ = "(C) 2008-2009 Martin Sandve Alnes and Simula Resarch Laboratory"
-__license__  = "GNU GPL Version 2, or (at your option) any later version"
+# Copyright (C) 2008-2009 Martin Sandve Alnes and Simula Resarch Laboratory
+#
+# This file is part of SyFi.
+#
+# SyFi is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 2 of the License, or
+# (at your option) any later version.
+#
+# SyFi is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with SyFi. If not, see <http://www.gnu.org/licenses/>.
+#
+# First added:  2008-08-13
+# Last changed: 2009-05-14
 
 import ufl
 from sfc.codegeneration.codeformatting import indent, CodeFormatter, gen_token_assignments
@@ -41,37 +56,48 @@ class DofMapCG:
 
     def generate_code_dict(self):
         vars = {
-            'classname'            : self.classname,
-            'constructor'          : indent(self.gen_constructor()),
-            'destructor'           : indent(self.gen_destructor()),
-            'signature'            : indent(self.gen_signature()),
-            'needs_mesh_entities'  : indent(self.gen_needs_mesh_entities()),
-            'init_mesh'            : indent(self.gen_init_mesh()),
-            'init_cell'            : indent(self.gen_init_cell()),
-            'init_cell_finalize'   : indent(self.gen_init_cell_finalize()),
-            'global_dimension'     : indent(self.gen_global_dimension()),
-            'local_dimension'      : indent(self.gen_local_dimension()),
-            'max_local_dimension'  : indent(self.gen_max_local_dimension()),
-            'geometric_dimension'  : indent(self.gen_geometric_dimension()),
-            'num_facet_dofs'       : indent(self.gen_num_facet_dofs()),
-            'num_entity_dofs'      : indent(self.gen_num_entity_dofs()),
-            'tabulate_dofs'        : indent(self.gen_tabulate_dofs()),
-            'tabulate_facet_dofs'  : indent(self.gen_tabulate_facet_dofs()),
-            'tabulate_entity_dofs' : indent(self.gen_tabulate_entity_dofs()),
-            'tabulate_coordinates' : indent(self.gen_tabulate_coordinates()),
-            'num_sub_dof_maps'     : indent(self.gen_num_sub_dof_maps()),
-            'create_sub_dof_map'   : indent(self.gen_create_sub_dof_map()),
-            'members'              : indent(self.gen_members()),
+            'classname'             : self.classname,
+            'constructor'           : indent(self.gen_constructor()),
+            "constructor_arguments" : indent(self.gen_constructor_arguments()),
+            "initializer_list"      : indent(self.gen_initializer_list()),
+            'destructor'            : indent(self.gen_destructor()),
+            "create"                : indent(self.gen_create()),
+            'signature'             : indent(self.gen_signature()),
+            'needs_mesh_entities'   : indent(self.gen_needs_mesh_entities()),
+            'init_mesh'             : indent(self.gen_init_mesh()),
+            'init_cell'             : indent(self.gen_init_cell()),
+            'init_cell_finalize'    : indent(self.gen_init_cell_finalize()),
+            'global_dimension'      : indent(self.gen_global_dimension()),
+            'local_dimension'       : indent(self.gen_local_dimension()),
+            'max_local_dimension'   : indent(self.gen_max_local_dimension()),
+            'geometric_dimension'   : indent(self.gen_geometric_dimension()),
+            "topological_dimension" : indent(self.gen_topological_dimension()),
+            'num_facet_dofs'        : indent(self.gen_num_facet_dofs()),
+            'num_entity_dofs'       : indent(self.gen_num_entity_dofs()),
+            'tabulate_dofs'         : indent(self.gen_tabulate_dofs()),
+            'tabulate_facet_dofs'   : indent(self.gen_tabulate_facet_dofs()),
+            'tabulate_entity_dofs'  : indent(self.gen_tabulate_entity_dofs()),
+            'tabulate_coordinates'  : indent(self.gen_tabulate_coordinates()),
+            'num_sub_dofmaps'       : indent(self.gen_num_sub_dofmaps()),
+            'create_sub_dofmap'     : indent(self.gen_create_sub_dofmap()),
+            'members'               : indent(self.gen_members()),
         }
         return vars
-    
 
     def gen_constructor(self):
-        code = ""
-        return code
+        return ""
+
+    def gen_constructor_arguments(self):
+        return ""
+
+    def gen_initializer_list(self):
+        return ""
 
     def gen_destructor(self):
-        code = ""
+        return ""
+
+    def gen_create(self):
+        code = "return new %s();" % self.classname
         return code
 
     def gen_signature(self):
@@ -80,6 +106,9 @@ class DofMapCG:
 
     def gen_needs_mesh_entities(self):
         """bool needs_mesh_entities(unsigned int d) const"""
+        if self.rep.ufl_element.family() == "Real":
+            return 'return false;'
+        
         # pick the mesh entities we need
         needs = tuple( [ ('true' if n else 'false') for n in self.rep.num_entity_dofs] )
         # return false when a type of mesh entities are not needed
@@ -94,6 +123,8 @@ class DofMapCG:
     def gen_init_mesh(self):
         """bool init_mesh(const mesh& m)"""
         nsd = self.rep.cell.nsd
+        if self.rep.ufl_element.family() == "Real":
+            return 'return false;'
         
         if not self.options.enable_dof_ptv:
             # compute and store global dimension
@@ -119,10 +150,12 @@ class DofMapCG:
         
         if not self.options.enable_dof_ptv:
             return ""
+        if self.rep.ufl_element.family() == "Real":
+            return ""
         
         # FIXME: This code needs updating, e.g. it doesn't handle mixed elements.
         
-        fe    = self.rep.syfi_element
+        #fe    = self.rep.syfi_element
         nsd   = self.rep.cell.nsd
         nbf   = self.rep.local_dimension
 
@@ -160,6 +193,9 @@ class DofMapCG:
     
     def gen_init_cell_finalize(self):
         """void init_cell_finalize()"""
+        if self.rep.ufl_element.family() == "Real":
+            return ""
+
         code = ""
         if self.options.enable_dof_ptv:
             #code += "dof.build_loc2glob();\n"
@@ -174,6 +210,8 @@ class DofMapCG:
 
     def gen_global_dimension(self):
         """unsigned int global_dimension() const"""
+        if self.rep.ufl_element.family() == "Real":
+            return 'return %d;' % self.rep.value_size
         return 'return _global_dimension;'
 
     def gen_local_dimension(self):
@@ -188,12 +226,17 @@ class DofMapCG:
         """unsigned int geometric_dimension() const"""
         return 'return %d;' % self.rep.cell.nsd
 
+    def gen_topological_dimension(self):
+        return "return %d;" % self.rep.cell.nsd
+
     def gen_num_facet_dofs(self):
         """unsigned int num_facet_dofs() const"""
         return "return %d;" % self.rep.num_facet_dofs
 
     def gen_num_entity_dofs(self):
         """unsigned int num_entity_dofs(unsigned int d) const"""
+        if self.rep.ufl_element.family() == "Real":
+            return 'return 0;'
         code = CodeFormatter()
         code.begin_switch("d")
         for i in range(self.rep.cell.nsd+1):
@@ -205,11 +248,14 @@ class DofMapCG:
         return str(code)
     
     def gen_tabulate_dofs(self):
+        if self.rep.ufl_element.family() == "Real":
+            return '\n'.join('dofs[%d] = %d;' % (i, i) for i in range(self.rep.value_size))
+
         if self.options.enable_dof_ptv:
             return self.gen_tabulate_dofs__dof_ptv()
         else:
             return self.gen_tabulate_dofs__implicit()
-    
+
     def gen_tabulate_dofs__implicit(self):
         """void tabulate_dofs(unsigned int* dofs,
                                const mesh& m,
@@ -308,6 +354,8 @@ class DofMapCG:
                                      unsigned int facet) const
         This implementation should be general for elements with point evaluation dofs on simplices.
         """
+        if self.rep.ufl_element.family() == "Real":
+            return 'throw std::runtime_error("tabulate_facet_dofs not implemented for Real elements.");'
         # generate code for each facet: for each facet i, tabulate local dofs[j]
         code = CodeFormatter()
         code.begin_switch("facet")
@@ -323,11 +371,13 @@ class DofMapCG:
         code.end_switch()
 
         return str(code)
-
+    
     def gen_tabulate_entity_dofs(self):
         """void tabulate_entity_dofs(unsigned int* dofs,
                                      unsigned int d, unsigned int i) const
         """
+        if self.rep.ufl_element.family() == "Real":
+            return 'throw std::runtime_error("tabulate_entity_dofs not implemented for Real elements.");'
         code = CodeFormatter()
         # define one case for each cell entity (d, i)
         code.begin_switch("d")
@@ -352,6 +402,8 @@ class DofMapCG:
     def gen_tabulate_coordinates(self):
         """void tabulate_coordinates(double** coordinates,
                                       const cell& c) const"""
+        if self.rep.ufl_element.family() == "Real":
+            return 'throw std::runtime_error("tabulate_coordinates not implemented for Real elements.");'
         code = CodeFormatter()
         code += gen_geometry_code(self.rep.cell.nsd, detG=False)
         for i in range(self.rep.local_dimension):
@@ -360,12 +412,12 @@ class DofMapCG:
                 code += "coordinates[%d][%d] = %s;" % (i, k, self.rep.dof_x[i][k].printc())
         return str(code)
 
-    def gen_num_sub_dof_maps(self):
-        """unsigned int num_sub_dof_maps() const"""
+    def gen_num_sub_dofmaps(self):
+        """unsigned int num_sub_dofmaps() const"""
         return "return %d;" % len(self.rep.sub_elements)
 
-    def gen_create_sub_dof_map(self):
-        """dof_map* create_sub_dof_map(unsigned int i) const"""
+    def gen_create_sub_dofmap(self):
+        """dofmap* create_sub_dofmap(unsigned int i) const"""
         if self.options.enable_dof_ptv:
             if len(self.rep.sub_elements) > 1:
                 code = CodeFormatter()
@@ -373,7 +425,7 @@ class DofMapCG:
                 for i, fe in enumerate(self.rep.sub_elements):
                     code += "case %d: return new %s(loc2glob, %s);" % (i, fe.dof_map_classname, self.constructor_arg_string2)
                 code.end_switch()
-                code += 'throw std::runtime_error("Invalid index in create_sub_dof_map.");'
+                code += 'throw std::runtime_error("Invalid index in create_sub_dofmap.");'
             else:
                 code = "return new %s(loc2glob, %s);" % (self.classname, self.constructor_arg_string2)
         else:
@@ -383,9 +435,9 @@ class DofMapCG:
                 for i, fe in enumerate(self.rep.sub_elements):
                     code += "case %d: return new %s();" % (i, fe.dof_map_classname)
                 code.end_switch()
-                code += 'throw std::runtime_error("Invalid index in create_sub_dof_map.");'
+                code += 'throw std::runtime_error("Invalid index in create_sub_dofmap.");'
             else:
-                code = "return new %s();" % self.classname
+                code = "return new %s();" % self.classname # FIXME: Should we throw error here instead now?
         return str(code)
 
     def gen_members(self):
@@ -397,7 +449,8 @@ class DofMapCG:
         #code += "protected:"
         code += "public:"
         code.indent()
-        code += "unsigned int _global_dimension;"
+        if self.rep.ufl_element.family() != "Real":
+            code += "unsigned int _global_dimension;"
 
         if self.options.enable_dof_ptv:
             code += "Dof_Ptv dof;"
