@@ -4,10 +4,25 @@
 This module contains code generation tools for the ufc::finite_element class.
 """
 
-__author__ = "Martin Sandve Alnes"
-__date__   = "2008-08-13 -- 2009-03-19"
-__copyright__ = "(C) 2008-2009 Martin Sandve Alnes and Simula Resarch Laboratory"
-__license__  = "GNU GPL Version 2, or (at your option) any later version"
+# Copyright (C) 2008-2009 Martin Sandve Alnes and Simula Resarch Laboratory
+#
+# This file is part of SyFi.
+#
+# SyFi is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 2 of the License, or
+# (at your option) any later version.
+#
+# SyFi is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with SyFi. If not, see <http://www.gnu.org/licenses/>.
+#
+# First added:  2008-08-13
+# Last changed: 2009-03-19
 
 from itertools import izip
 import ufl
@@ -43,12 +58,19 @@ class FiniteElementCG:
         vars = {
             "classname"                      : self.classname,
             "constructor"                    : indent(self.gen_constructor()),
+            "constructor_arguments"          : indent(self.gen_constructor_arguments()),
+            "initializer_list"               : indent(self.gen_initializer_list()),
             "destructor"                     : indent(self.gen_destructor()),
+            "create"                         : indent(self.gen_create()),
             "signature"                      : indent(self.gen_signature()),
             "cell_shape"                     : indent(self.gen_cell_shape()),
+            "geometric_dimension"            : indent(self.gen_geometric_dimension()),
+            "topological_dimension"          : indent(self.gen_topological_dimension()),
             "space_dimension"                : indent(self.gen_space_dimension()),
             "value_rank"                     : indent(self.gen_value_rank()),
             "value_dimension"                : indent(self.gen_value_dimension()),
+            "map_from_reference_cell"        : indent(self.gen_map_from_reference_cell()),
+            "map_to_reference_cell"          : indent(self.gen_map_to_reference_cell()),
             "evaluate_basis"                 : indent(self.gen_evaluate_basis()),
             "evaluate_basis_all"             : indent(self.gen_evaluate_basis_all()),
             "evaluate_basis_derivatives"     : indent(self.gen_evaluate_basis_derivatives()),
@@ -58,19 +80,29 @@ class FiniteElementCG:
             "interpolate_vertex_values"      : indent(self.gen_interpolate_vertex_values()),
             "num_sub_elements"               : indent(self.gen_num_sub_elements()),
             "create_sub_element"             : indent(self.gen_create_sub_element()),
-            "members"                        : indent(self.gen_members())
+            "members"                        : indent(self.gen_members()),
         }
         return vars
-    
+
     def generate_support_code(self):
         return ""
 
     def gen_constructor(self):
         return ""
 
+    def gen_constructor_arguments(self):
+        return ""
+
+    def gen_initializer_list(self):
+        return ""
+
     def gen_destructor(self):
         return ""
 
+    def gen_create(self):
+        code = "return new %s();" % self.classname
+        return code
+
     def gen_signature(self):
         """const char* signature() const"""
         return 'return "%s";' % self.signature
@@ -79,6 +111,12 @@ class FiniteElementCG:
         """shape cell_shape() const"""
         return "return ufc::%s;" % self.rep.cell.shape
 
+    def gen_geometric_dimension(self):
+        return "return %d;" % self.rep.cell.nsd
+
+    def gen_topological_dimension(self):
+        return "return %d;" % self.rep.cell.nsd
+
     def gen_space_dimension(self):
         """unsigned int space_dimension() const"""
         return "return %d;" % self.rep.local_dimension
@@ -100,7 +138,13 @@ class FiniteElementCG:
             code += 'throw std::runtime_error("Invalid dimension for rank %d value.");\n' % self.rep.value_rank
 
         return code
-    
+
+    def gen_map_from_reference_cell(self):
+        return 'throw std::runtime_error("Not implemented.");' # FIXME
+
+    def gen_map_to_reference_cell(self):
+        return 'throw std::runtime_error("Not implemented.");' # FIXME
+
     def gen_evaluate_basis(self):
         """void evaluate_basis(unsigned int i,
                                 double* values,
@@ -114,15 +158,27 @@ class FiniteElementCG:
         nbf = self.rep.local_dimension
         value_shape = self.rep.value_shape
         value_size = self.rep.value_size
-        
+
+        if self.rep.ufl_element.family() == "Real":
+            code = []
+            if value_size > 1:
+                code += ["memset(values, 0, sizeof(double)*%d);" % value_size]
+            code += ['values[i] = 1.0;']
+            return '\n'.join(code)
+
         # symbols for output values
         val_sym = symbols(["values[%d]" % d for d in range(value_size)])
-        
+
         # generate code body
         code = CodeFormatter()
-        
+
+        code += gen_geometry_code(nsd, detG=False, GinvT=True)
+
+        coordinates = swiginac.matrix(nsd, 1, symbols(["coordinates[%d]" % i for i in range(nsd)]))
+        xi = self.rep.GinvT.transpose().mul(coordinates - self.rep.p0).evalm()
+
         for i in range(nsd):
-            code += "const double %s = coordinates[%d];" % (("x","y","z")[i],i)
+            code += "const double %s = %s;" % (("x","y","z")[i], xi[i].printc())
         
         if value_size > 1:
             code += "memset(values, 0, sizeof(double)*%d);" % value_size
@@ -188,6 +244,7 @@ class FiniteElementCG:
                                            const double* coordinates,
                                            const cell& c) const
         """
+
         code = CodeFormatter()
         code += "for(unsigned i = 0; i < %d; i++)" % self.rep.local_dimension
         code.begin_block()
@@ -210,6 +267,9 @@ class FiniteElementCG:
         nbf = self.rep.local_dimension
         value_shape = self.rep.value_shape
         value_size = self.rep.value_size
+
+        if self.rep.ufl_element.family() == "Real":
+            return '\n'.join('values[%d] = 0.0;' % d for d in range(value_size))
         
         sfc_assert(self.DN_order <= 2, "Don't support computing higher order derivatives (yet).")
         
@@ -303,7 +363,7 @@ class FiniteElementCG:
         code.dedent()
         code.end_switch()
         return str(code)
-    
+
     def gen_evaluate_dof(self):
         """double evaluate_dof(unsigned int i,
                                const function& f,
@@ -313,7 +373,6 @@ class FiniteElementCG:
            TODO: Implement support for normal and tangential component dofs.
            TODO: Implement for elements without point evaluation dofs.
         """
-        
         # some useful variables
         nsd = self.rep.cell.nsd
         nbf = self.rep.local_dimension
@@ -323,7 +382,7 @@ class FiniteElementCG:
         code.new_text( gen_geometry_code(nsd, detG=False) )
         code += "double v[%d];" % self.rep.value_size
         code += "double x[%d];" % nsd
-        
+
         # fill global coordinates of dof in x[]
         if nbf == 1:
             # skip the switch if only one basis function
@@ -338,13 +397,16 @@ class FiniteElementCG:
                     code += "x[%d] = %s;" % (k, self.rep.dof_x[i][k].printc())
                 code.end_case()
             code.end_switch()
-        
+
         # Evaluate the function (this evaluates all value components!)
         code += "f.evaluate(v, x, c);"
-        
+
         # dofs for a single sub element are numbered contiguously:
         # i = (nbf / valsize) * value_component
-        code += "return v[i / %d];" % (nbf // self.rep.value_size)
+        if nbf == 1:
+            code += "return v[0];"
+        else:
+            code += "return v[i / %d];" % (nbf // self.rep.value_size)
         
         return str(code)
 
@@ -376,7 +438,7 @@ class FiniteElementCG:
         # symbols for input array entries
         dof_values_sym    = symbols("dof_values[%d]" % i    for i in xrange(nbf))
         vertex_values_sym = symbols("vertex_values[%d]" % i for i in xrange(nv*value_size))
-        
+
         # the spatial symbols u is expressed in
         p = self.rep.p
 
@@ -399,7 +461,7 @@ class FiniteElementCG:
         
         code = gen_token_assignments( izip(vertex_values_sym, vertex_values) )
         return code
-    
+
     def gen_num_sub_elements(self):
         """unsigned int num_sub_elements() const"""
         return  "return %d;" % len(self.rep.sub_elements)
@@ -414,7 +476,7 @@ class FiniteElementCG:
             code.end_switch()
             code += 'throw std::runtime_error("Invalid index in create_sub_element.");'
         else:
-            code = "return new %s();" % self.classname
+            code = "return new %s();" % self.classname # FIXME: Should we throw error here instead now?
         return str(code)
 
     def gen_members(self):
