@@ -2,7 +2,7 @@
 
 from sfc.common.version import version
 from sfc.common.ParameterDict import ParameterDict
-from sfc.common.options import default_options
+from sfc.common.options import default_parameters
 from sfc.common.paths import get_abs_ufc_h_path
 from sfc.common.output import sfc_debug, sfc_info, sfc_warning, sfc_error, sfc_assert, write_file
 from sfc.common.output import get_log_handler, get_logger, set_log_handler, set_logging_level
