@@ -5,13 +5,27 @@ This module contains the Just-In-Time compiler tools.
 The main function is jit(form, options), see its documentation.
 """
 
-__author__ = "Martin Sandve Alnes"
-__date__   = "2008-09-04 -- 2009-04-23"
-__copyright__ = "(C) 2008-2009 Martin Sandve Alnes and Simula Resarch Laboratory"
-__license__  = "GNU GPL Version 2, or (at your option) any later version"
-
-#Modified by Kent-Andre Mardal 2010 
-
+# Copyright (C) 2008-2009 Martin Sandve Alnes and Simula Resarch Laboratory
+#
+# This file is part of SyFi.
+#
+# SyFi is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 2 of the License, or
+# (at your option) any later version.
+#
+# SyFi is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with SyFi. If not, see <http://www.gnu.org/licenses/>.
+#
+# Modified by Kent-Andre Mardal, 2010.
+#
+# First added:  2008-09-04
+# Last changed: 2009-04-23
 
 import shutil
 import os
@@ -23,7 +37,7 @@ import ufl.algorithms
 from ufl.algorithms import preprocess
 
 from sfc.common import version
-from sfc.common import default_options
+from sfc.common import default_parameters
 from sfc.common import ParameterDict
 from sfc.common import get_abs_ufc_h_path
 from sfc.common import sfc_debug, sfc_info, sfc_warning, sfc_error, sfc_assert, write_file
@@ -33,13 +47,14 @@ from sfc.codegeneration import generate_code, compiler_input
 def cache_signature(input, options):
     "A signature string uniquely identifying jit input."
 
-# FIXME, need to use i.form_data() for memory caching 
+    # FIXME, need to use i.form_data() for memory caching  TODO: What does this mean?
     if not isinstance(input, list):
         input = [input]
     newinput = []
     for i in input:
         if isinstance(i, ufl.form.Form):
-            i = i.signature() 
+            i = i.signature()
+            #i = i.compute_form_data().preprocessed_form.signature() # TODO: Something like this?
         newinput.append(i)
     return "sfc.jit(%r, %r) # SFC version %r" % (newinput, options, version)
 
@@ -75,9 +90,7 @@ def compile_module(module_dir, hfilenames, cfilenames, signature, options):
         os.chdir(orig_dir)
 
 def jit(input, parameters=None, common_cell=None):
-
-
-    ufl_elements, formdatas = compiler_input(input)
+    ufl_elements, formdatas = compiler_input(input, common_cell=common_cell)
 
     # Merge parameters with defaults
     if parameters is None:
@@ -94,7 +107,7 @@ def jit(input, parameters=None, common_cell=None):
 
     # Build module signature and classnames from input
     signature = cache_signature(input, parameters)
-    formclassnames = [form_classname(fd._form, parameters) for fd in formdatas]
+    formclassnames = [form_classname(fd.preprocessed_form, parameters) for fd in formdatas]
 #    formclassnames = [form_classname(fd.form, parameters) for fd in formdatas]
     dmclassnames = [dof_map_classname(e) for e in ufl_elements]
     feclassnames = [finite_element_classname(e) for e in ufl_elements]
@@ -141,12 +154,13 @@ def jit(input, parameters=None, common_cell=None):
             write_file("parameters.repr", repr(parameters))
             write_file("signature", signature)
             for fd in formdatas:
-                write_file("%s.repr" % short_name("form_", fd.name), repr(fd._form))
+                write_file("%s.repr" % short_name("form_", fd.name), repr(fd.preprocessed_form))
             for ue in ufl_elements:
                 write_file("%s.repr" % short_name("element_", base_element_classname(ue)), repr(ue))
-            
+
             # Generate code!
-            hfilenames, cfilenames = generate_code(ufl_elements + formdatas, None, parameters)
+            hfilenames, cfilenames = generate_code(ufl_elements + formdatas, None,
+                                                   parameters, common_cell=common_cell)
             
             # Hook for profiling without the C++ compilation
             if parameters.compilation.skip:
@@ -171,15 +185,12 @@ def jit(input, parameters=None, common_cell=None):
     # If we get here, 'module' should be our compiled module.
     
     # TODO: Handle mixed list of forms and elements?
-    
-    # Got forms, return forms
-#    if formdatas:
-#        ufc_forms = [getattr(module, name) for name in formclassnames]
-#        return ufc_forms[0], module, formdatas[0]
 
+    # Got forms, return forms
     if formdatas:
+        prefix = "sfc dummy prefix for pydolfin which I have no idea what is used for"
         ufc_forms = [getattr(module, name)() for name in formclassnames]
-        return ufc_forms[0], module, formdatas[0]
+        return ufc_forms[0], module, formdatas[0], prefix
 
     # Got elements, return elements
     elif ufl_elements:
@@ -190,8 +201,7 @@ def jit(input, parameters=None, common_cell=None):
     sfc_error(msg)
 
 
-
-def jitf(input, objects, parameters = None, common_cell=None):
+def jitf(input, objects, parameters = None):
     """Generate code from input and parameters.
     
     @param input:
@@ -204,8 +214,8 @@ def jitf(input, objects, parameters = None, common_cell=None):
 
     # To handle all input uniformly
     list_input = isinstance(input, list)
-    ufl_elements, formdatas = compiler_input(input, objects)
-    
+    ufl_elements, formdatas = compiler_input(input, objects=objects)
+
     # Merge parameters with defaults
     if parameters is None:
         parameters = default_parameters()
@@ -221,7 +231,7 @@ def jitf(input, objects, parameters = None, common_cell=None):
 
     # Build module signature and classnames from input
     signature = cache_signature(input, parameters)
-    formclassnames = [form_classname(fd._form, parameters) for fd in formdatas]
+    formclassnames = [form_classname(fd.preprocessed_form, parameters) for fd in formdatas]
     dmclassnames = [dof_map_classname(e) for e in ufl_elements]
     feclassnames = [finite_element_classname(e) for e in ufl_elements]
 
@@ -266,12 +276,13 @@ def jitf(input, objects, parameters = None, common_cell=None):
             write_file("parameters.repr", repr(parameters))
             write_file("signature", signature)
             for fd in formdatas:
-                write_file("%s.repr" % short_name("form_", fd.name), repr(fd._form))
+                write_file("%s.repr" % short_name("form_", fd.name), repr(fd.preprocessed_form))
             for ue in ufl_elements:
                 write_file("%s.repr" % short_name("element_", base_element_classname(ue)), repr(ue))
             
             # Generate code!
-            hfilenames, cfilenames = generate_code(ufl_elements + formdatas, objects, parameters)
+            hfilenames, cfilenames = generate_code(ufl_elements + formdatas, objects,
+                                                   parameters)
             
             # Hook for profiling without the C++ compilation
             if parameters.compilation.skip:
@@ -299,11 +310,12 @@ def jitf(input, objects, parameters = None, common_cell=None):
     
     # Got forms, return forms
     if formdatas:
+        prefix = "sfc dummy prefix for pydolfin which I have no idea what is used for"
         ufc_forms = [getattr(module, name) for name in formclassnames]
         if list_input:
-            return ufc_forms(), module, formdatas
+            return ufc_forms, module, formdatas, [prefix]*len(ufc_forms)
         else:
-            return ufc_forms[0], module, formdatas[0]
+            return ufc_forms[0], module, formdatas[0], prefix
 
     # Got elements, return elements
     elif ufl_elements:
@@ -315,4 +327,3 @@ def jitf(input, objects, parameters = None, common_cell=None):
     
     msg = "Nothing to return, this shouldn't happen.\ninput =\n%r" % repr(input)
     sfc_error(msg)
-
