@@ -4,11 +4,25 @@
 This module contains a class for representing quadrature rules.
 """
 
-__author__ = "Martin Sandve Alnes"
-__date__   = "November 29th 2007"
-__copyright__ = "(C) 2007 Martin Sandve Alnes and Simula Resarch Laboratory"
-__license__  = "GNU GPL Version 2, or (at your option) any later version"
-
+# Copyright (C) 2007 Martin Sandve Alnes and Simula Resarch Laboratory
+#
+# This file is part of SyFi.
+#
+# SyFi is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 2 of the License, or
+# (at your option) any later version.
+#
+# SyFi is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with SyFi. If not, see <http://www.gnu.org/licenses/>.
+#
+# First added:  November 29th 2007
+# Last changed: November 29th 2007
 
 class QuadRule:
     """This class represents a specific quadrature rule over a polygon."""
