@@ -5,13 +5,27 @@ This module contains functions and classes converting
 from UFL to internal SyFi representations of elements.
 """
 
-
-__author__ = "Martin Sandve Alnes"
-__date__   = "2008-08-13 -- 2008-12-16"
-__copyright__ = "(C) 2008 Martin Sandve Alnes and Simula Resarch Laboratory"
-__license__  = "GNU GPL Version 2, or (at your option) any later version"
-
-# Modified by Kent-Andre Mardal 2010 
+# Copyright (C) 2008 Martin Sandve Alnes and Simula Resarch Laboratory
+#
+# This file is part of SyFi.
+#
+# SyFi is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 2 of the License, or
+# (at your option) any later version.
+#
+# SyFi is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with SyFi. If not, see <http://www.gnu.org/licenses/>.
+#
+# Modified by Kent-Andre Mardal, 2010.
+#
+# First added:  2008-08-13
+# Last changed: 2008-12-16
 
 import operator
 import ufl
@@ -24,7 +38,7 @@ from sfc.symbolic_utils import grad, ddx, symbols, symbolic_matrix
 from sfc.geometry import UFCCell
 from sfc.common.names import finite_element_classname, dof_map_classname
 from sfc.common import sfc_assert, sfc_info, sfc_warning, sfc_error, sfc_debug
-from sfc.common.options import default_options
+from sfc.common.options import default_parameters
 
 def product(sequence):
     return reduce(operator.__mul__, sequence, 1)
@@ -134,7 +148,8 @@ class ElementRepresentation(object):
                  # Geometry symbols:
                  "p0", "p", "G", "GinvT",
                  )
-    def __init__(self, ufl_element, quad_rule=None, options=None, cache=None, common_cell=None):
+
+    def __init__(self, ufl_element, quad_rule=None, options=None, cache=None):
         sfc_debug("Entering ElementRepresentation.__init__")
         
         # Handle input and default values
@@ -142,7 +157,7 @@ class ElementRepresentation(object):
         self.ufl_element = ufl_element
         self.quad_rule = quad_rule
         if options is None:
-            self.options = default_options() 
+            self.options = default_parameters() 
         else:
             self.options = options
         if cache is None:
@@ -155,12 +170,6 @@ class ElementRepresentation(object):
         
         # Geometry information
         self.ufl_cell = self.ufl_element.cell()
-        
-        # make sure that the element has a cell in case of Expressions etc.  
-        if common_cell: 
-            self.ufl_element.set_cell(common_cell)
-
-        self.ufl_cell = self.ufl_element.cell()
         self.polygon = create_syfi_polygon(self.ufl_cell.domain())
         self.cell = UFCCell(self.polygon)
         
@@ -216,9 +225,14 @@ class ElementRepresentation(object):
             self.syfi_element = None
             self.local_dimension = self.facet_quad_rule.num_points # TODO: *num_facets?
         
+        elif self.ufl_element.family() == "Real":
+            # No SyFi element, local dimension equals value size
+            self.syfi_element = None
+            self.local_dimension = self.value_size
+        
         else:
             # Make SyFi element
-            self.syfi_element = create_syfi_element(self.ufl_element, self.polygon, default_order=options.code.finite_element.default_order_of_element)
+            self.syfi_element = create_syfi_element(self.ufl_element, self.polygon, default_order=self.options.code.finite_element.default_order_of_element)
             self.local_dimension = self.syfi_element.nbf()
         
         # utility symbols
@@ -261,7 +275,10 @@ class ElementRepresentation(object):
         
         elif self.ufl_element.family() == "Quadrature":
             xi = swiginac.matrix(nsd, 1, self.quad_rule.points[i])
-            
+
+        elif self.ufl_element.family() == "Real":
+            xi = swiginac.matrix(nsd, 1, [0.0]*nsd)
+
         else:
             # check if the element is a scalar or vector element
             dofi = self.syfi_element.dof(i)
@@ -300,7 +317,7 @@ class ElementRepresentation(object):
             dof_x  = (self.G.mul(dof_xi).add(self.p0)).evalm() # TODO: Assumes affine mapping!
             self.dof_x.append(dof_x)
     
-    def _build_entity_dofs(self):
+    def _build_entity_dofs(self): # XXXReal: Does not make sense for Real
         "Build dof vs mesh entity relations."
 
         # TODO: This may be optimized if necessary for mixed elements, but maybe we don't care.
@@ -311,14 +328,16 @@ class ElementRepresentation(object):
             lists = [[] for j in range(self.cell.num_entities[i])]
             self.entity_dofs.append(lists)
         
-        if self.ufl_element.family() == "Discontinuous Lagrange" \
-            or self.ufl_element.family() == "Quadrature":
+        if self.ufl_element.family() in ("Discontinuous Lagrange", "Quadrature"):
             # associate all dofs with the cell
             self.entity_dofs[self.topological_dimension][0] = list(range(self.local_dimension))
         
         elif self.ufl_element.family() == "Boundary Quadrature":
             sfc_error("Boundary Quadrature not handled.")
-        
+
+        elif self.ufl_element.family() == "Real":
+            pass #sfc_error("Real elements not handled.")
+
         else:
             # NB! Assuming location dof_xi coordinates match topological entity!
             # build dof list for each cell entity
@@ -350,13 +369,12 @@ class ElementRepresentation(object):
         # ... build a list of dofs for each facet:
         self.facet_dofs = [[] for j in range(self.cell.num_facets)]
         
-        if self.ufl_element.family() == "Discontinuous Lagrange" \
-            or self.ufl_element.family() == "Quadrature":
+        if self.ufl_element.family() in ("Discontinuous Lagrange", "Quadrature", "Real"):
             pass # no dofs on facets
         
         elif self.ufl_element.family() == "Boundary Quadrature":
             sfc_error("Boundary Quadrature not handled.")
-        
+
         else:
             # for each facet j, loop over the reference coordinates 
             # for all dofs i and check if the dof is on the facet
@@ -426,6 +444,10 @@ class ElementRepresentation(object):
         elif "Quadrature" in self.ufl_element.family():
             sfc_error("Cannot compute basis functions for quadrature element.")
             N = swiginac.numeric(1.0)
+
+        elif "Real" in self.ufl_element.family():
+            #sfc_error("Cannot compute basis functions for Real element.") # XXXReal: Will we use this or not?
+            N = swiginac.numeric(1.0)
         
         else:
             # Basic element, get basis function from SyFi
