@@ -3,10 +3,25 @@
 This module contains a representation class for forms, storing information about all form aspects.
 """
 
-__author__ = "Martin Sandve Alnes"
-__date__   = "2008-08-13 -- 2009-04-19"
-__copyright__ = "(C) 2008-2009 Martin Sandve Alnes and Simula Resarch Laboratory"
-__license__  = "GNU GPL Version 2, or (at your option) any later version"
+# Copyright (C) 2008-2009 Martin Sandve Alnes and Simula Resarch Laboratory
+#
+# This file is part of SyFi.
+#
+# SyFi is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 2 of the License, or
+# (at your option) any later version.
+#
+# SyFi is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with SyFi. If not, see <http://www.gnu.org/licenses/>.
+#
+# First added:  2008-08-13
+# Last changed: 2009-04-19
 
 import copy
 import math
@@ -15,7 +30,8 @@ import swiginac
 import SyFi
 
 import ufl
-from ufl.algorithms import extract_max_quadrature_element_degree, estimate_quadrature_degree, estimate_max_polynomial_degree
+from ufl.algorithms import extract_max_quadrature_element_degree,\
+    estimate_quadrature_degree, estimate_total_polynomial_degree
 
 from sfc.common import sfc_assert
 from sfc.common.names import finite_element_classname, dof_map_classname, \
@@ -39,7 +55,7 @@ class FormRepresentation(object):
         self.options   = options
         
         # Fetch some common variables from formdata for shorter names in rest of code
-        self.form             = self.formdata._form
+        self.form             = self.formdata.preprocessed_form
         self.rank             = self.formdata.rank
         self.num_coefficients = self.formdata.num_coefficients
         self.domain           = self.formdata.cell.domain()
@@ -70,7 +86,7 @@ class FormRepresentation(object):
         if d is None:
             d = estimate_quadrature_degree(self.form) # TODO: Option for which estimation method to choose!
         if d is None:
-            d = estimate_max_polynomial_degree(self.form)
+            d = estimate_total_polynomial_degree(self.form)
         sfc_assert(d is not None, "All quadrature degree estimation rules failed, this shouldn't happen!")
         self.quad_order = d 
         
