@@ -3,12 +3,27 @@
 This module contains representation classes for integrals.
 """
 
-__author__ = "Martin Sandve Alnes"
-__date__   = "2008-08-13 -- 2009-03-12"
-__copyright__ = "(C) 2008-2009 Martin Sandve Alnes and Simula Resarch Laboratory"
-__license__  = "GNU GPL Version 2, or (at your option) any later version"
-
-# Modified by Kent-Andre Mardal 2010 
+# Copyright (C) 2008-2009 Martin Sandve Alnes and Simula Resarch Laboratory
+#
+# This file is part of SyFi.
+#
+# SyFi is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 2 of the License, or
+# (at your option) any later version.
+#
+# SyFi is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with SyFi. If not, see <http://www.gnu.org/licenses/>.
+#
+# Modified by Kent-Andre Mardal, 2010.
+#
+# First added:  2008-08-13
+# Last changed: 2009-03-12
 
 from itertools import izip
 
