@@ -1,13 +1,27 @@
 """This module defines evaluation algorithms for converting
 converting UFL expressions to swiginac representation."""
 
-__authors__ = "Martin Sandve Alnes"
-__date__ = "2008-08-22 -- 2009-03-19"
-__copyright__ = "(C) 2008-2009 Martin Sandve Alnes and Simula Resarch Laboratory"
-__license__  = "GNU GPL Version 2, or (at your option) any later version"
-
-
-# Modified by Kent-Andre Mardal 2010 
+# Copyright (C) 2008-2009 Martin Sandve Alnes and Simula Resarch Laboratory
+#
+# This file is part of SyFi.
+#
+# SyFi is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 2 of the License, or
+# (at your option) any later version.
+#
+# SyFi is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with SyFi. If not, see <http://www.gnu.org/licenses/>.
+#
+# Modified by Kent-Andre Mardal, 2010.
+#
+# First added:  2008-08-22
+# Last changed: 2009-03-19
 
 from collections import defaultdict
 from itertools import izip, chain
@@ -73,8 +87,6 @@ class EvaluateAsSwiginac(MultiFunction):
         sfc_assert(self.on_facet, "Expecting to be on a facet in facet_normal.")
 
         if derivatives:
-            if o.cell().degree() != 1:
-                sfc_warning("Higher order cells not implemented.")
             return swiginac.numeric(0)
         
         if component:
@@ -109,7 +121,7 @@ class EvaluateAsSwiginac(MultiFunction):
     def coefficient(self, o, component=(), derivatives=()):
         # Assuming renumbered arguments!
         iarg = o.count()
-        sfc_assert(iarg >= 0, "Function count shouldn't be negative.")
+        sfc_assert(iarg >= 0, "Coefficient count shouldn't be negative.")
         sfc_assert(isinstance(component, tuple), "Expecting tuple for component.")
 
         if derivatives:
@@ -142,8 +154,8 @@ class EvaluateAsSwiginac(MultiFunction):
     
     def indexed(self, o, A, ii):
         # Passes on control to one of:
-        #def basis_function(self, o, component):
-        #def function(self, o, component):
+        #def argument(self, o, component):
+        #def coefficient(self, o, component):
         #def facet_normal(self, o, component):
         #def spatial_coordinate(self, o, component):
         #def spatial_derivative(self, o, component):
@@ -254,7 +266,7 @@ class SwiginacEvaluator(Transformer):
         c = self.component()
         v = 1 if c[0] == c[1] else 0
         return swiginac.numeric(v)
-    
+
     def argument(self, x):
         iarg = x.count()
         sfc_assert(iarg >= 0, "Argument count shouldn't be negative.")
@@ -287,7 +299,7 @@ class SwiginacEvaluator(Transformer):
     
     def variable(self, x):
         return self.visit(x._expression)
-    
+
     def garbage(self, x): # TODO: Maybe some of the ideas here can be used in code generation
         c = self.component()
         index_values = tuple(self._index2value[k] for k in x._expression.free_indices())
@@ -467,7 +479,6 @@ class SwiginacEvaluator(Transformer):
         
         # --- Handle derivatives of geometry objects
         if isinstance(f, FacetNormal):
-            sfc_assert(f.cell().order() == 1, "Higher order geometries not implemented.")
             return swiginac.numeric(0.0)
         
         if isinstance(f, SpatialCoordinate):
