@@ -5,10 +5,25 @@ This module contains utility functions for symbolic computations,
 mostly a thin layer on top of swiginac.
 """
 
-__author__ = "Martin Sandve Alnes"
-__date__   = "2007-10-16 -- 2009-03-19"
-__copyright__ = "(C) 2007-2009 Martin Sandve Alnes and Simula Resarch Laboratory"
-__license__  = "GNU GPL Version 2, or (at your option) any later version"
+# Copyright (C) 2007-2009 Martin Sandve Alnes and Simula Resarch Laboratory
+#
+# This file is part of SyFi.
+#
+# SyFi is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 2 of the License, or
+# (at your option) any later version.
+#
+# SyFi is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with SyFi. If not, see <http://www.gnu.org/licenses/>.
+#
+# First added:  2007-10-16
+# Last changed: 2009-03-19
 
 import swiginac
 import SyFi
