@@ -1,5 +1,19 @@
-// Copyright (C) 2006-2009 Kent-Andre Mardal and Simula Research Laboratory.
-// Licensed under the GNU GPL Version 2, or (at your option) any later version.
+// Copyright (C) 2006-2009 Kent-Andre Mardal and Simula Research Laboratory
+//
+// This file is part of SyFi.
+//
+// SyFi is free software: you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 2 of the License, or
+// (at your option) any later version.
+//
+// SyFi is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with SyFi. If not, see <http://www.gnu.org/licenses/>.
 
 #include <sstream>
 
@@ -1426,9 +1440,9 @@ namespace SyFi
 			{
 				for (unsigned int k=1; k< d; k++)
 				{
-					if ( d - i - j -k  >= 1 )
+					if ( int(d) - int(i) - int(j) - int(k)  >= 1 )
 					{
-						l= d - i - j -k;
+						l= int(d) - int(i) - int(j) - int(k);
 						ex sum = (l*V1m + k*V2m + j*V3m + i*V4m)/d;
 						ret.append(matrix_to_lst2(sum.evalm()));
 					}
