@@ -1,5 +1,19 @@
-// Copyright (C) 2006-2009 Kent-Andre Mardal and Simula Research Laboratory.
-// Licensed under the GNU GPL Version 2, or (at your option) any later version.
+// Copyright (C) 2006-2009 Kent-Andre Mardal and Simula Research Laboratory
+//
+// This file is part of SyFi.
+//
+// SyFi is free software: you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 2 of the License, or
+// (at your option) any later version.
+//
+// SyFi is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with SyFi. If not, see <http://www.gnu.org/licenses/>.
 
 #include "RaviartThomas.h"
 #include <fstream>
@@ -51,9 +65,6 @@ namespace SyFi
 			}
 			else if ( p->str().find("Triangle") != string::npos )
 			{
-
-				cout <<"should be here "<<endl;
-
 				description = istr("RaviartThomas_", order) + "_2D";
 
 				Triangle& triangle = (Triangle&)(*p);
@@ -258,7 +269,7 @@ namespace SyFi
 					Triangle triangle = tetrahedron.triangle(i);
 					GiNaC::lst normal_vec = normal(tetrahedron, i);
 					GiNaC::ex Vn = inner(pspace, normal_vec);
-					GiNaC::lst points = interior_coordinates(triangle, order);
+					GiNaC::lst points = interior_coordinates(triangle, order-1);
 					GiNaC::ex triangle_size = triangle.integrate(GiNaC::numeric(1));
 
 					GiNaC::ex point;
@@ -276,7 +287,7 @@ namespace SyFi
 				if ( order > 1)
 				{
 
-					GiNaC::lst points = interior_coordinates(tetrahedron, order-1);
+					GiNaC::lst points = interior_coordinates(tetrahedron, order-2);
 					GiNaC::ex point;
 					for (unsigned int j=0; j< points.nops(); j++)
 					{
