@@ -46,7 +46,7 @@ int main() {
     vector_ii vec; 
     pair<unsigned int,unsigned int> index; 
     Ptv exdof; 
-    for (unsigned int i=0; i< dof.size(); i++) {
+    for (int i=0; i< dof.size(); i++) {
         exdof = dof.glob_dof(i); 
         cout <<"global dof " <<i<<" dof "<<exdof<<endl; 
 //        vec = dof.glob2loc(i);
