@@ -9,7 +9,7 @@ void example_of_use(FE& fe) {
     ex Ni; 
     ex gradNi; 
     ex dofi; 
-    for (int i=0; i< fe.nbf() ; i++) { 
+    for (unsigned int i=0; i< fe.nbf() ; i++) { 
         Ni = fe.N(i); 
         gradNi = grad(Ni); 
         dofi = fe.dof(i); 
@@ -37,7 +37,7 @@ int main(){
     // regression test
 
     archive ar; 
-    for (int i=0; i< fe.nbf(); i++) {
+    for (unsigned int i=0; i< fe.nbf(); i++) {
 	    ar.archive_ex(fe.N(i) , istr("N",i).c_str()); 
 	    ar.archive_ex(fe.dof(i) , istr("D",i).c_str()); 
     }
