@@ -18,9 +18,9 @@ int main() {
     fe.set_order(order); 
     fe.set_polygon(T); 
     fe.compute_basis_functions(); 
-    for (int i=0; i< fe.nbf() ; i++) {
+    for (unsigned int i=0; i< fe.nbf() ; i++) {
         index.first = i; 
-        for (int j=0; j< fe.nbf() ; j++) {
+        for (unsigned int j=0; j< fe.nbf() ; j++) {
             index.second = j; 
             ex nabla = inner(grad(fe.N(i)), grad(fe.N(j))); 
             ex Aij = T.integrate(nabla);   
