@@ -31,7 +31,7 @@ int main() {
 
     Rectangle rectangle(p0,p1) ;
     ex basis = polynom_space.op(2); 
-    for (int i=0; i< basis.nops(); i++) {
+    for (unsigned int i=0; i< basis.nops(); i++) {
         cout <<"i "<<i<<endl; 
         ex integrand = p*basis.op(i); 
         ex ai = rectangle.integrate(integrand); 
