@@ -21,7 +21,7 @@ int main() {
     cout <<"l.repr "<<l_repr<<endl; 
 
 
-    for (int i=0; i< l_repr.nops(); i++) {
+    for (unsigned int i=0; i< l_repr.nops(); i++) {
         cout <<"l_repr.op(" <<i<<"):  "<<l_repr.op(i)<<endl; 
     }
 
