@@ -21,10 +21,10 @@ int main () {
     pfe.set_order(order); 
     pfe.compute_basis_functions(); 
 
-    for (int i=0; i< vfe.nbf(); i++) 
+    for (unsigned int i=0; i< vfe.nbf(); i++) 
         cout <<"vfe.N("<<i<<")="<<vfe.N(i)<<endl; 
 
-    for (int i=0; i< pfe.nbf(); i++) 
+    for (unsigned int i=0; i< pfe.nbf(); i++) 
         cout <<"pfe.N("<<i<<")="<<pfe.N(i)<<endl; 
 
     return 0; 
