@@ -13,7 +13,7 @@ int main() {
     Robust fe(triange); 
     fe.compute_basis_functions(); 
 
-    for (int i=0; i< fe.nbf(); i++) { 
+    for (unsigned int i=0; i< fe.nbf(); i++) { 
 
         cout <<"fe.N("<<i<<")= "<<fe.N(i)<<endl; 
         cout <<"div(fe.N("<<i<<"))= "<<(div(fe.N(i))).expand()<<endl; 
@@ -24,7 +24,7 @@ int main() {
     // regression test
     archive ar; 
 
-    for (int i=0; i< fe.nbf(); i++) { 
+    for (unsigned int i=0; i< fe.nbf(); i++) { 
         ar.archive_ex(fe.N(i), istr("N",i).c_str()); 
         ar.archive_ex((div(fe.N(i))).expand(), istr("divN",i).c_str()); 
     }
