@@ -17,7 +17,7 @@ int main() {
     lst list2 = lst(pi,x,f); 
     cout <<"list="<<lst2string(list2)<<endl; 
 
-    for (int i=0; i< list.nops(); i++) {
+    for (unsigned int i=0; i< list.nops(); i++) {
         cout <<"item "<<i+1<<" = "<<list[i]<<endl; 
     }
 
